@@ -3,11 +3,13 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
-from elements_sdk.api.ai_api import AIApi
+from elements_sdk.api.aws_api import AWSApi
 from elements_sdk.api.auth_api import AuthApi
 from elements_sdk.api.automation_api import AutomationApi
+from elements_sdk.api.integrations_api import IntegrationsApi
 from elements_sdk.api.main_api import MainApi
 from elements_sdk.api.media_library_api import MediaLibraryApi
 from elements_sdk.api.status_api import StatusApi
 from elements_sdk.api.storage_api import StorageApi
 from elements_sdk.api.tape_archive_api import TapeArchiveApi
+from elements_sdk.api.tasks_api import TasksApi
